#
# spec file for package dtkcore
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2024Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libver  5
%define apiver  5.5.0
%define pkg_ver 5.5
%define gtest_version %(rpm -q --queryformat '%%{VERSION}' gtest)

Name:           dtkcore
Version:        5.5.33
Release:        2.6
Summary:        Deepin Tool Kit Core
License:        LGPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxdeepin/dtkcore
Source0:        https://github.com/linuxdeepin/dtkcore/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTEAM Fix-library-link.patch hillwood@opensuse.org - Need link to dl
Patch0:         Fix-library-link.patch
BuildRequires:  dtkcommon
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  pkgconfig(gsettings-qt)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Deepint Tool Kit (Dtk) is the base devlopment tool of all C++/Qt Developer work
on Deepin.

You shoud read the [Deepin Application Specification](doc/Specification)
firstly.

%package -n lib%{name}%{libver}
Summary:        Deepin Toolkit Core libraries
Group:          System/Libraries
Requires:       deepin-desktop-base
Recommends:     qt5integration

%description -n lib%{name}%{libver}
Deepint Tool Kit (Dtk) is the base devlopment tool of all C++/Qt Developer work
on Deepin.

%package devel
Summary:        Development tools for dtkcore
Group:          Development/Languages/C and C++
Requires:       dtkcommon
Requires:       lib%{name}%{libver} = %{version}

%description devel
The dtkcore-devel package contains the header files and developer
docs for dtkcore.

You shoud firstly read the "Deepin Application Specification".

%prep
%autosetup -p1
# sed -i 's/system(lrelease/system(lrelease-qt5/g' src/dtk_translation.prf
sed -i 's|#!/usr/bin/env python3|#!/usr/bin/python3|g' tools/script/dtk-license.py
sed -i 's|#!/usr/bin/env python3|#!/usr/bin/python3|g' tools/script/dtk-translate.py
%if "%{gtest_version}" >= "1.14.0"
sed -i 's|c++11|c++14|g' tests/tests.pro
%endif

%build
%qmake5 DEFINES+=QT_NO_DEBUG_OUTPUT \
        PREFIX=%{_prefix} \
        LIB_INSTALL_DIR=%{_libdir} \
        lrelease=lrelease-qt5
%make_build

%install
%qmake5_install

# Remove useless files
rm -rf %{buildroot}/usr/tests
chmod +x %{buildroot}%{_libdir}/libdtk-5.5.0/DCore/bin/*.py

%post -n lib%{name}%{libver} -p /sbin/ldconfig
%postun -n lib%{name}%{libver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md CHANGELOG.md
%license LICENSE
%{_bindir}/qdbusxml2cpp-fix
%{_libdir}/libdtk-%{apiver}

%files -n lib%{name}%{libver}
%defattr(-,root,root,-)
%{_libdir}/lib%{name}.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libdtk-%{apiver}
%dir %{_libdir}/qt5
%dir %{_libdir}/qt5/mkspecs
# %{_libdir}/qt5/mkspecs/features
%{_libdir}/qt5/mkspecs/modules
%dir %{_libdir}/cmake
%{_libdir}/cmake/*

%changelog
* Thu Mar 28 2024 Hillwood Yang <hillwood@opensuse.org>
- Fix build on gtest 1.14.0
* Fri Aug 26 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.33
  * Support abc field for os-version
  * Check value field while loading dconfigfile
* Sat Jun 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.32
  * Fix dtkcore_config.h miss include some Class
  * Fix DConfig can't find resource
  * Fix application crash when dconfig is invalid
* Mon Apr  4 2022 Hillwood Yang <hillwoodroc@gmail.com>
- Update version to 5.5.30
  * Add data type check for config
  * Add interface for Dconfig
  * Add DStandardPaths::paths(DSG type) interface
  * Remove assert in ensureOsVersion
  * Fix bugs
* Mon Feb 14 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.23
  * Fix bugs
  * dtkVersionString return empty string
  * update DTK_VERSION
  * recode DConf Class
- Drop fix-return-type.patch, fixed by upstream
* Sun Aug  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update pkgconfig profile version to 5.5
* Sun Jul 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.17.1
  * Add qdbusxml2cpp-fix
  * update abi json file
  * Renaming a nonexistent file will report an error
  * Add global function to get dtk Version
  * Export DObjectPrivate
- Add fix-return-type.patch, fix return type error.
* Tue Jun  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Change Requires to Recommends for qt5integration, fix cycle dependence
  for dtkgui and dtkwidget
* Wed May  5 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.13
  * Split some files to dtkcommon
  * Update apiversion to 5.5.0
  * Fix bugs
  * Add qdbusxml2cpp-fix
- Add Fix-library-link.patch
* Tue Feb 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Need deepin-desktop-base
* Fri Jan 29 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.0
  * Fix correct tools output message typo
  * Fix memory leak in dsettings
  * Fix bug for desktop
* Tue Sep 15 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.2.2.5
  * Fix bugs
  * Add class DThreadUtils
  * Fix ID in os-release
* Mon Apr 27 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.2.0
  * Switch to LGPLv3 license
  * Fix bug-20975 DSettings::reset emit too many valueChanged
  * Fix ix tow tag on same commit
  * Support get installed memory size from lshw
  * Fix stderr warning from deepin-os-release tool
  * Add personal edition support and check
  * Add class template argument for overrideVfptrFun
  * Support override global vtable of class
  * Add ddeDisplayName() for DDE applications
* Sun Aug  4 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.1.1
  * Fix the pkg-config "Requires" values
  * Adjust responsibility of the prf files
  * Fix dtk-settings binary location for libdtkcore-bin package
* Tue Jul 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.0.16.1
  * feat: allow dtk-settings-tools skip json key translation
  * refactor: use commit count for the package version
* Sun Jul  7 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.0.15
  * Fix DSettings: crash when calling getOption() if option doesn't exist
  * refactor: use commit count for the package version
  * feat: allow dtk-settings-tools skip json key translation
* Fri Apr 19 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.0.12.1
  * Cross-builds incorrectly, built packages contain paths from build
    architecture
  * Fix issue#10
* Tue Apr 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.0.10
  * Fix crash at application
  * Add DNotifySender
  * Deepin-os-release support cpu model and other info query
  * Fix failed build the deepin-os-release on Qt 5.7.1
  * Use main project c/cxx/ld flags on build deepin-os-release
  * Fix missing default constructor
  * Support connan build
* Thu Dec 20 2018 hillwood@opensuse.org
- Update version to 2.0.9.11
  * Fix include unistd.h instead of sys/unistd.h
  * Fix url encoding
  * Fix compatibility with Qt 5.6
  * Fix can't get correct disk size in some case
  * add DRecentManager class
* Fri Nov  9 2018 hillwood@opensuse.org
- Update version to 2.0.9.5
  * update version number for expermimental
  * remove qt symbols
  * non array type value is wrong on parse josn file
  * update symbols
  * add LIBDTKCORESHARED_EXPORT for windows
  * add symbols
* Mon Mar 19 2018 hillwood@opensuse.org
- Split cmake-dtkcore
- Update version to 2.0.7.1
  * reset short cut not show
  * cmake link depends
  * better static lib support
  * read settings value failed
  * set default should not use
  * fix dtk-settings install path
  * develop package no install the "version.pri" file
  * awk script failed
  * set default build version for debian changelog
  * set its value only if VERSION is empty
  * add hide support for group
  * add get option interface
  * add group interface for DSettingsGroup
  * support generate cmake with qt function
  * config pkg config with dtk_module
  * support qt module
  * add the "version.pri" file
  * remove build version from install path
  * make version parser easier
  * set verion when build
  * add .qmake.conf file
  * add DtkCore and dtkcore_config.h headers
  * DSettings: support set default value
* Thu Feb  1 2018 hillwood@opensuse.org
- Update version to 2.0.6
  * Add cmake package search configure
* Thu Nov 30 2017 hillwood@opensuse.org
- Update to 2.0.5.2
  * make macosx build success
  * windows build failed
  * add macro D_DECL_DEPRECATED
  * build failed on used dbasefilewatcher.h project ([34fbe4b3](34fbe4b3))
  * add miss libgsettings-qt-dev ([f61c1b54](f61c1b54))
  * not select python version ([7e7e8832](7e7e8832))
  * support gsettingsbackend, remove dsettings-key ([26a29800](26a29800))
  * create gsettingsbackend ([b94b97b1](b94b97b1))
* Fri Nov  3 2017 jengelh@inai.de
- Expand summary.
* Thu Nov  2 2017 dimstar@opensuse.org
- Set Group for shared library package to 'System/Libraries'.
* Thu Sep 28 2017 hillwood@opensuse.org
- Initial package.
